candidates_grid

Function candidates_grid 

pub fn candidates_grid(puzzle: &str) -> Result<Vec<Vec<Vec<u8>>>, RustokuError>
Returns the candidate digits for every cell as a 9×9 grid.

Filled cells return an empty Vec. Empty cells return the digits (1–9) still possible for that cell given the current constraints.