pub fn generate_str(difficulty: &str) -> Result<String, RustokuError>Expand description
Generates a puzzle for the given difficulty string and returns it as an 81-char string.
pub fn generate_str(difficulty: &str) -> Result<String, RustokuError>Generates a puzzle for the given difficulty string and returns it as an 81-char string.