Core module for the Rustoku solver and generator.
This module includes the Rustoku struct for representing and solving Sudoku puzzles using
backtracking and Minimum Remaining Values (MRV). It provides functionality for solving
puzzles and checking solutions.
This module also includes a function to generate new Sudoku puzzles with a specified number of clues, ensuring that the generated puzzle has a unique solution.
Structs
- Board
- Raw 9x9 board with some useful helpers.
- Candidates
- Represents the candidates cache for a Rustoku puzzle.
- Masks
- Masks for Rustoku puzzle, representing the state of rows, columns, and boxes.
- Rustoku
- Solver primitive that uses backtracking and bitmasking for constraints.
- Rustoku
Builder - A simple builder for constructing
Rustokuwith fluent configuration. - Solution
- Solved board and its solution path.
- Solutions
- Lazy iterator wrapper for solutions. Uses an explicit DFS stack and yields solutions one-by-one without computing them all up-front.
- Solve
Path - Solve path associated with a solution.
- Technique
Flags - Bitflags indicating which human techniques are active/enabled.
Enums
- Solve
Step - Single step in the solving process.
Functions
- generate_
board - Generates a new Sudoku puzzle with a unique solution.